import unittest
import copy
import json
from . import ValidatorTest
from .. import validate_string

VALID_MALWARE = """
{
  "type": "malware",
  "id": "malware--0c7b5b88-8ff7-4a4d-aa9d-feb398cd0061",
  "created": "2016-05-12T08:17:27.000000Z",
  "modified": "2016-05-12T08:17:27.000000Z",
  "name": "Cryptolocker",
  "description": "...",
  "labels": ["ransomware"]
}
"""


class MalwareTestCases(ValidatorTest):
    valid_malware = json.loads(VALID_MALWARE)

    def test_wellformed_malware(self):
        results = validate_string(VALID_MALWARE, self.options)
        self.assertTrue(results.is_valid)

    def test_vocab_malware_label(self):
        malware = copy.deepcopy(self.valid_malware)
        malware['labels'] += "something"
        malware = json.dumps(malware)
        results = validate_string(malware, self.options)
        self.assertEqual(results.is_valid, False)

        self.check_ignore(malware, 'malware-label')

    def test_open_vocab_format_uppercase(self):
        malware = copy.deepcopy(self.valid_malware)
        malware['labels'] += "Ransomware"
        malware = json.dumps(malware)
        self.assertFalseWithOptions(malware,
                                    disabled='malware-label')

    def test_open_vocab_format_underscore(self):
        malware = copy.deepcopy(self.valid_malware)
        malware['labels'] += "ransom_ware"
        malware = json.dumps(malware)
        self.assertFalseWithOptions(malware,
                                    disabled='malware-label')

    def test_open_vocab_format_space(self):
        malware = copy.deepcopy(self.valid_malware)
        malware['labels'] += "ransom ware"
        malware = json.dumps(malware)
        self.assertFalseWithOptions(malware,
                                    disabled='malware-label')


if __name__ == "__main__":
    unittest.main()
